from setuptools import setup, find_packages

setup(
    name="Shadowamino",  # Your package name
    version="1.0",  # Your package version
    packages=find_packages(),  # Finds all the packages in your project
    install_requires=[],  # List dependencies here
    description="Aminoapps lib not all func working but I test some",
    long_description_content_type="text/markdown",  # Specify content type for Markdown
    url="https://github.com/6ndw/shadowamino",  # GitHub URL
    author="Shadow",
    author_email="tmhat2374@gmail.com",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)
